@@ -12,6 +12,7 @@ import re
 import logging
 import unicodedata
 import colorsys
+from decimal import Decimal
 from functools import partial
 from tryton.config import CONFIG
 from tryton.config import TRYTON_ICON, PIXMAPS_DIR
@@ -175,6 +176,14 @@ MODELHISTORY = ModelHistory()
 class ViewSearch(object):
     searches = {}
 
+    def __init__(self):
+        class Encoder(PYSONEncoder):
+            def default(self, obj):
+                if isinstance(obj, Decimal):
+                    return float(obj)
+                return super(Encoder, self).default(obj)
+        self.encoder = Encoder()
+
     def load_searches(self):
         try:
             self.searches = rpc.execute('model', 'ir.ui.view_search',
@@ -191,7 +200,7 @@ class ViewSearch(object):
                 'create', [{
                         'model': model,
                         'name': name,
-                        'domain': PYSONEncoder().encode(domain),
+                        'domain': self.encoder.encode(domain),
                         }])
         except RPCException:
             return
@@ -306,13 +315,17 @@ def get_sensible_widget(window):
 
 
 def center_window(window, parent, sensible):
-    parent_x, parent_y = sensible.get_window().get_origin()
-    window_allocation = window.get_allocation()
     sensible_allocation = sensible.get_allocation()
-    x = (parent_x + sensible_allocation.x +
-        int((sensible_allocation.width - window_allocation.width) / 2))
-    y = (parent_y + sensible_allocation.y +
-        int((sensible_allocation.height - window_allocation.height) / 2))
+    if hasattr(sensible.get_window(), 'get_root_coords'):
+        x, y = sensible.get_window().get_root_coords(
+            sensible_allocation.x, sensible_allocation.y)
+    else:
+        x, y = sensible.get_window().get_origin()
+        x += sensible_allocation.x
+        y += sensible_allocation.y
+    window_allocation = window.get_allocation()
+    x = x + int((sensible_allocation.width - window_allocation.width) / 2)
+    y = y + int((sensible_allocation.height - window_allocation.height) / 2)
     window.move(x, y)
 
 
@@ -343,7 +356,7 @@ def selection(title, values, alwaysask=False):
     scrolledwindow.add(treeview)
     dialog.vbox.pack_start(scrolledwindow, True, True)
 
-    treeview.get_selection().set_mode('single')
+    treeview.get_selection().set_mode(gtk.SELECTION_SINGLE)
     cell = gtk.CellRendererText()
     column = gtk.TreeViewColumn("Widget", cell, text=0)
     treeview.append_column(column)
@@ -770,9 +783,11 @@ class ConcurrencyDialog(UniqueDialog):
             return True
         if res == gtk.RESPONSE_APPLY:
             from tryton.gui.window import Window
-            Window.create(False, resource, res_id=obj_id,
+            Window.create(resource,
+                res_id=obj_id,
                 domain=[('id', '=', obj_id)],
-                context=context, mode=['form', 'tree'])
+                context=context,
+                mode=['form', 'tree'])
         return False
 
 concurrency = ConcurrencyDialog()
@@ -1151,6 +1166,7 @@ def generateColorscheme(masterColor, keys, light=0.1):
 class RPCException(Exception):
 
     def __init__(self, exception):
+        super(RPCException, self).__init__(exception)
         self.exception = exception
 
 
@@ -1187,9 +1203,9 @@ class RPCProgress(object):
             # Parent is only useful if it is asynchronous
             # otherwise the cursor is not updated.
             self.parent = get_toplevel_window()
-            if self.parent.window:
+            if self.parent.get_window():
                 watch = gtk.gdk.Cursor(gtk.gdk.WATCH)
-                self.parent.window.set_cursor(watch)
+                self.parent.get_window().set_cursor(watch)
             thread.start_new_thread(self.start, ())
             return
         else:
@@ -1197,8 +1213,8 @@ class RPCProgress(object):
             return self.process()
 
     def process(self):
-        if self.parent and self.parent.window:
-            self.parent.window.set_cursor(None)
+        if self.parent and self.parent.get_window():
+            self.parent.get_window().set_cursor(None)
         if self.exception:
             if self.process_exception_p:
                 def rpc_execute(*args):
@@ -1386,3 +1402,10 @@ def get_label_attributes(readonly, required):
     if hasattr(pango, 'AttrStyle'):
         attrlist.change(pango.AttrStyle(style, 0, -1))
     return attrlist
+
+
+def ellipsize(string, length):
+    if len(string) <= length:
+        return string
+    ellipsis = _('...')
+    return string[:length - len(ellipsis)] + ellipsis
